@@ -1,4 +1,4 @@
-#Copyright ReportLab Europe Ltd. 2000-2012
+#Copyright ReportLab Europe Ltd. 2000-2016
 #see license.txt for license details
 #history http://www.reportlab.co.uk/cgi-bin/viewcvs.cgi/public/reportlab/trunk/reportlab/docs/userguide/ch2_graphics.py
 from tools.docco.rl_doc_utils import *
@@ -292,7 +292,7 @@ heading3("Image methods")
 pencilnote()
 disc("""
 You need the Python Imaging Library (PIL) to use images with the ReportLab package.
-Examnples of the techniques below can be found by running the script $test_pdfgen_general.py$
+Examples of the techniques below can be found by running the script $test_pdfgen_general.py$
 in our $tests$ subdirectory and looking at page 7 of the output.
 """)
 
