@@ -1,4 +1,4 @@
-#Copyright ReportLab Europe Ltd. 2000-2012
+#Copyright ReportLab Europe Ltd. 2000-2016
 #see license.txt for license details
 #history http://www.reportlab.co.uk/cgi-bin/viewcvs.cgi/public/reportlab/trunk/reportlab/docs/userguide/ch5_paragraphs.py
 from tools.docco.rl_doc_utils import *
@@ -64,6 +64,11 @@ class ParagraphStyle(PropertySet):
         'borderRadius': None,
         'allowWidows': 1,
         'allowOrphans': 0,
+        'textTransform':None,
+        'endDots':None,
+        'splitLongWords':1,
+        'underlineProportion': _baseUnderlineProportion,
+        'bulletAnchor': 'start',
         }
 """)
 
@@ -165,6 +170,12 @@ The default color of the text can be set with $textColor$ and the paragraph back
 colour can be set with $backColor$. The paragraph's border properties may be changed using
 $borderWidth$, $borderPadding$, $borderColor$ and $borderRadius$.""")
 
+disc("""The $textTransform$ attribute can be <b><i>None</i></b>, <i>'upper'</i> or <i>'lower'</i> to get the obvious result.""")
+disc("""Attribute $endDots$ can be <b><i>None</i></b>, a string, or an object with attributes text and optional fontName, fontSize, textColor,  backColor
+and dy(y offset) to specify trailing matter on the last line of left/right justified paragraphs.""")
+disc("""The $splitLongWords$ attribute can be set to a false value to avoid splitting very long words.""")
+disc("""The $underLineProportion$ attribute can be set to a true or false value to control whether underlines are proportional to the font size.""")
+disc("""Attribute $bulletAnchor$ can be <i>'start'</i>, <i>'middle'</i>, <i>'end'</i> or <i>'numeric'</i> to control where the bullet is anchored.""")
 
 heading2("Paragraph XML Markup Tags")
 disc("""XML markup can be used to modify or specify the
@@ -225,7 +236,7 @@ outermost paragraph tag.""")
 
 
 heading2("Intra-paragraph markup")
-disc("""'<![CDATA[Within each paragraph, we use a basic set of XML tags
+disc("""<![CDATA[Within each paragraph, we use a basic set of XML tags
 to provide markup.  The most basic of these are bold (<b>...</b>),
 italic (<i>...</i>) and underline (<u>...</u>).
 Other tags which are allowed are strong (<strong>...</strong>), and strike through (<strike>...</strike>). The <link> and <a> tags
@@ -271,15 +282,18 @@ of the peace.  How do you plead?""", "The $font$ tag")
 
 heading3("Superscripts and Subscripts")
 disc("""Superscripts and subscripts are supported with the
-<![CDATA[<super> and <sub> tags, which work exactly
-as you might expect.  In addition, most greek letters
+<![CDATA[<super>/<sup> and <sub> tags, which work exactly
+as you might expect. Additionally these three tags have
+attributes rise and size to optionally set the rise/descent
+and font size for the  superscript/subscript text.
+In addition, most greek letters
 can be accessed by using the <greek></greek>
 tag, or with mathML entity names.]]>""")
 
 ##parabox2("""<greek>epsilon</greek><super><greek>iota</greek>
 ##<greek>pi</greek></super> = -1""", "Greek letters and subscripts")
 
-parabox2("""Equation (&alpha;): <greek>e</greek> <super><greek>ip</greek></super>  = -1""",
+parabox2("""Equation (&alpha;): <greek>e</greek> <super rise=9 size=6><greek>ip</greek></super>  = -1""",
          "Greek letters and superscripts")
 
 heading3("Inline Images")
