@@ -1,9 +1,9 @@
-#Copyright ReportLab Europe Ltd. 2000-2012
+#Copyright ReportLab Europe Ltd. 2000-2016
 #see license.txt for license details
-#history http://www.reportlab.co.uk/cgi-bin/viewcvs.cgi/public/reportlab/trunk/reportlab/__init__.py
-__version__=''' $Id$ '''
 __doc__="""The Reportlab PDF generation library."""
-Version = "3.1.44"
+Version = "3.3.0"
+__version__=Version
+__date__='20160217'
 
 import sys, os, imp
 
@@ -44,5 +44,5 @@ try:
 except ImportError:
     try:
         _fake_import(os.path.expanduser(os.path.join('~','.reportlab_mods')),'reportlab_mods')
-    except ImportError:
+    except (ImportError,KeyError):
         pass
