@@ -1,8 +1,8 @@
-#Copyright ReportLab Europe Ltd. 2000-2012
+#Copyright ReportLab Europe Ltd. 2000-2016
 #see license.txt for license details
 #history http://www.reportlab.co.uk/cgi-bin/viewcvs.cgi/public/reportlab/trunk/reportlab/graphics/charts/legends.py
 
-__version__=''' $Id$ '''
+__version__='3.3.0'
 __doc__="""This will be a collection of legends to be used with charts."""
 
 import copy, operator
@@ -334,10 +334,10 @@ class Legend(Widget):
         xW = dx+dxTextSpace+self.autoXPadding
         variColumn = self.variColumn
         if variColumn:
-            width = reduce(operator.add,[m[-1] for m in maxWidth],0)+xW*nCols
+            width = sum([m[-1] for m in maxWidth])+xW*nCols
         else:
             deltax = max(maxWidth[-1]+xW,deltax)
-            width = maxWidth[-1]+nCols*deltax
+            width = nCols*deltax
             maxWidth = nCols*[maxWidth]
 
         thisx = self.x
@@ -372,7 +372,7 @@ class Legend(Widget):
             dividerOffsX = self.dividerOffsX
             dividerOffsY = self.dividerOffsY
 
-        for i in range(n):
+        for i in xrange(n):
             if autoCP:
                 col = autoCP
                 col.index = i
