@@ -1,7 +1,7 @@
-#Copyright ReportLab Europe Ltd. 2000-2004
+#Copyright ReportLab Europe Ltd. 2000-2016
 #see license.txt for license details
 #history http://www.reportlab.co.uk/cgi-bin/viewcvs.cgi/public/reportlab/trunk/reportlab/graphics/widgets/grids.py
-__version__=''' $Id: grids.py 3660 2010-02-08 18:17:33Z damian $ '''
+__version__='3.3.0'
 
 from reportlab.lib import colors
 from reportlab.lib.validators import isNumber, isColorOrNone, isBoolean, isListOfNumbers, OneOf, isListOfColors, isNumberOrNone
@@ -374,7 +374,7 @@ class ShadedRect(Widget):
         numShades = self.numShades
         if self.cylinderMode:
             if not numShades%2: numShades = numShades+1
-            halfNumShades = (numShades-1)/2 + 1
+            halfNumShades = int((numShades-1)/2) + 1
         num = float(numShades) # must make it float!
         vertical = self.orientation == 'vertical'
         if vertical:
@@ -424,7 +424,13 @@ def colorRange(c0, c1, n):
 
 def centroid(P):
     '''compute average point of a set of points'''
-    return reduce(lambda x,y, fn=float(len(P)): (x[0]+y[0]/fn,x[1]+y[1]/fn),P,(0,0))
+    cx = 0
+    cy = 0
+    for x,y in P:
+        cx+=x
+        cy+=y
+    n = float(len(P))
+    return cx/n, cy/n
 
 def rotatedEnclosingRect(P, angle, rect):
     '''
@@ -446,10 +452,10 @@ def rotatedEnclosingRect(P, angle, rect):
     def orthogonalAxisDist(xy,s=s,c=c,x0=x0,y0=y0):
         x,y = xy
         return (c*(y-y0)+s*(x-x0))
-    L = map(parallelAxisDist,P)
+    L = list(map(parallelAxisDist,P))
     L.sort()
     a0, a1 = L[0], L[-1]
-    L = map(orthogonalAxisDist,P)
+    L = list(map(orthogonalAxisDist,P))
     L.sort()
     b0, b1 = L[0], L[-1]
     rect.x, rect.width = a0, a1-a0
@@ -479,16 +485,23 @@ class ShadedPolygon(Widget,LineShape):
 
     def draw(self):
         P = self.points
-        P = map(lambda i, P=P:(P[i],P[i+1]),xrange(0,len(P),2))
-        path = definePath([('moveTo',)+P[0]]+map(lambda x: ('lineTo',)+x,P[1:])+['closePath'],
+        P = list(map(lambda i, P=P:(P[i],P[i+1]),range(0,len(P),2)))
+        path = definePath([('moveTo',)+P[0]]+[('lineTo',)+x for x in P[1:]]+['closePath'],
             fillColor=None, strokeColor=None)
         path.isClipPath = 1
         g = Group()
         g.add(path)
-        rect = ShadedRect(strokeWidth=0,strokeColor=None)
+        angle = self.angle
+        orientation = 'vertical'
+        if angle==180:
+            angle = 0
+        elif angle in (90,270):
+            orientation ='horizontal'
+            angle = 0
+        rect = ShadedRect(strokeWidth=0,strokeColor=None,orientation=orientation)
         for k in 'fillColorStart', 'fillColorEnd', 'numShades', 'cylinderMode':
             setattr(rect,k,getattr(self,k))
-        g.add(rotatedEnclosingRect(P, self.angle, rect))
+        g.add(rotatedEnclosingRect(P, angle, rect))
         g.add(EmptyClipPath)
         path = path.copy()
         path.isClipPath = 0
