@@ -1,7 +1,7 @@
-#Copyright ReportLab Europe Ltd. 2000-2012
+#Copyright ReportLab Europe Ltd. 2000-2016
 #see license.txt for license details
 #history http://www.reportlab.co.uk/cgi-bin/viewcvs.cgi/public/reportlab/trunk/reportlab/platypus/flowables.py
-__version__=''' $Id$ '''
+__version__='3.3.0'
 __doc__="""
 A flowable is a "floating element" in a document whose exact position is determined by the
 other elements that precede it, such as a paragraph, a diagram interspersed between paragraphs,
@@ -30,9 +30,10 @@ from reportlab.lib.colors import red, gray, lightgrey
 from reportlab.lib.rl_accel import fp_str
 from reportlab.lib.enums import TA_LEFT, TA_CENTER, TA_RIGHT, TA_JUSTIFY
 from reportlab.lib.styles import _baseFontName
+from reportlab.lib.utils import strTypes
 from reportlab.pdfbase import pdfutils
 from reportlab.pdfbase.pdfmetrics import stringWidth
-from reportlab.rl_config import _FUZZ, overlapAttachedSpace, ignoreContainerActions
+from reportlab.rl_config import _FUZZ, overlapAttachedSpace, ignoreContainerActions, listWrapOnFakeWidth
 import collections
 
 __all__=('TraceInfo','Flowable','XBox','Preformatted','Image','Spacer','PageBreak','SlowPageBreak',
@@ -40,6 +41,7 @@ __all__=('TraceInfo','Flowable','XBox','Preformatted','Image','Spacer','PageBrea
         'FailOnWrap','HRFlowable','PTOContainer','KeepInFrame','UseUpSpace',
         'ListFlowable','ListItem','DDIndenter','LIIndenter',
         'DocAssign', 'DocExec', 'DocAssert', 'DocPara', 'DocIf', 'DocWhile',
+        'PageBreakIfNotEmpty',
         )
 class TraceInfo:
     "Holder for info about where an object originated"
@@ -382,17 +384,20 @@ class Preformatted(Flowable):
 
 class Image(Flowable):
     """an image (digital picture).  Formats supported by PIL/Java 1.4 (the Python/Java Imaging Library
-       are supported.  At the present time images as flowables are always centered horozontally
-       in the frame. We allow for two kinds of lazyness to allow for many images in a document
+       are supported. Images as flowables may be aligned horizontally in the
+       frame with the hAlign parameter - accepted values are 'CENTER',
+       'LEFT' or 'RIGHT' with 'CENTER' being the default.
+       We allow for two kinds of lazyness to allow for many images in a document
        which could lead to file handle starvation.
        lazy=1 don't open image until required.
        lazy=2 open image when required then shut it.
     """
     _fixedWidth = 1
     _fixedHeight = 1
-    def __init__(self, filename, width=None, height=None, kind='direct', mask="auto", lazy=1):
+    def __init__(self, filename, width=None, height=None, kind='direct',
+                 mask="auto", lazy=1, hAlign='CENTER'):
         """If size to draw at not specified, get it from the image."""
-        self.hAlign = 'CENTER'
+        self.hAlign = hAlign
         self._mask = mask
         fp = hasattr(filename,'read')
         if fp:
@@ -465,7 +470,9 @@ class Image(Flowable):
         if a=='_img':
             from reportlab.lib.utils import ImageReader  #this may raise an error
             self._img = ImageReader(self._file)
-            del self._file
+            if not isinstance(self._file,strTypes):
+                self._file = None
+                if self._lazy>=2: self._lazy = 1    #here we're assuming we cannot read again
             return self._img
         elif a in ('drawWidth','drawHeight','imageWidth','imageHeight'):
             self._setup_inner()
@@ -487,7 +494,7 @@ class Image(Flowable):
                                 mask=self._mask,
                                 )
         if lazy>=2:
-            self._img = None
+            self._img = self._file = None
             self._lazy = lazy
 
     def identity(self,maxLen=None):
@@ -530,10 +537,15 @@ class UseUpSpace(NullDraw):
 class PageBreak(UseUpSpace):
     """Move on to the next page in the document.
        This works by consuming all remaining space in the frame!"""
+    def __init__(self,nextTemplate=None):
+        self.nextTemplate = nextTemplate
 
 class SlowPageBreak(PageBreak):
     pass
 
+class PageBreakIfNotEmpty(PageBreak):
+    pass
+
 class CondPageBreak(Spacer):
     """use up a frame if not enough vertical space effectively CondFrameBreak"""
     def __init__(self, height):
@@ -553,10 +565,12 @@ class CondPageBreak(Spacer):
     def identity(self,maxLen=None):
         return repr(self).replace(')',',frame=%s)'%self._frameName())
 
-def _listWrapOn(F,availWidth,canv,mergeSpace=1,obj=None,dims=None):
+def _listWrapOn(F,availWidth,canv,mergeSpace=1,obj=None,dims=None,fakeWidth=None):
     '''return max width, required height for a list of flowables F'''
     doct = getattr(canv,'_doctemplate',None)
     cframe = getattr(doct,'frame',None)
+    if fakeWidth is None:
+        fakeWidth = listWrapOnFakeWidth
     if cframe:
         from reportlab.platypus.doctemplate import _addGeneratedContent, Indenter
         doct_frame = cframe
@@ -581,7 +595,7 @@ def _listWrapOn(F,availWidth,canv,mergeSpace=1,obj=None,dims=None):
             if cframe:
                 _addGeneratedContent(F,cframe)
             if w<=_FUZZ or h<=_FUZZ: continue
-            W = max(W,min(w,availWidth))
+            W = max(W,min(w,availWidth) if fakeWidth else w)
             H += h
             if not atTop:
                 h = f.getSpaceBefore()
@@ -685,6 +699,9 @@ class Macro(Flowable):
     def draw(self):
         exec(self.command, globals(), {'canvas':self.canv})
 
+def _nullCallable(*args,**kwds):
+    pass
+
 class CallerMacro(Flowable):
     '''
     like Macro, but with callable command(s)
@@ -692,11 +709,10 @@ class CallerMacro(Flowable):
     wrapCallable(self,aW,aH)
     '''
     def __init__(self, drawCallable=None, wrapCallable=None):
-        _ = lambda *args: None
-        self._drawCallable = drawCallable or _
-        self._wrapCallable = wrapCallable or _
+        self._drawCallable = drawCallable or _nullCallable
+        self._wrapCallable = wrapCallable or _nullCallable
     def __repr__(self):
-        return "CallerMacro(%s)" % repr(self.command)
+        return "CallerMacro(%r,%r)" % (self._drawCallable,self._wrapCallable)
     def wrap(self, aW, aH):
         self._wrapCallable(self,aW,aH)
         return (0,0)
@@ -921,10 +937,10 @@ class PTOContainer(_Container,Flowable):
         n = len(C)
         I2W = {}
         dLeft = dRight = 0
-        for x in range(n):
+        for x in xrange(n):
             c = C[x]
             I = c._ptoinfo
-            if I not in list(I2W.keys()):
+            if I not in I2W.keys():
                 T = I.trailer
                 Hdr = I.header
                 tW, tH = _listWrapOn(T, availWidth, self.canv)
@@ -1029,12 +1045,13 @@ def _qsolve(h,ab):
     return max(1./s1, 1./s2)
 
 class KeepInFrame(_Container,Flowable):
-    def __init__(self, maxWidth, maxHeight, content=[], mergeSpace=1, mode='shrink', name='',hAlign='LEFT',vAlign='BOTTOM'):
+    def __init__(self, maxWidth, maxHeight, content=[], mergeSpace=1, mode='shrink', name='',hAlign='LEFT',vAlign='BOTTOM', fakeWidth=None):
         '''mode describes the action to take when overflowing
             error       raise an error in the normal way
             continue    ignore ie just draw it and report maxWidth, maxHeight
             shrink      shrinkToFit
             truncate    fit as much as possible
+            set fakeWidth to False to make _listWrapOn do the 'right' thing
         '''
         self.name = name
         self.maxWidth = maxWidth
@@ -1047,6 +1064,7 @@ class KeepInFrame(_Container,Flowable):
         self._content = content or []
         self.vAlign = vAlign
         self.hAlign = hAlign
+        self.fakeWidth = fakeWidth
 
     def _getAvailableWidth(self):
         return self.maxWidth - self._leftExtraIndent - self._rightExtraIndent
@@ -1062,7 +1080,8 @@ class KeepInFrame(_Container,Flowable):
         mode = self.mode
         maxWidth = float(min(self.maxWidth or availWidth,availWidth))
         maxHeight = float(min(self.maxHeight or availHeight,availHeight))
-        W, H = _listWrapOn(self._content,maxWidth,self.canv)
+        fakeWidth = self.fakeWidth
+        W, H = _listWrapOn(self._content,maxWidth,self.canv, fakeWidth=fakeWidth)
         if (mode=='error' and (W>maxWidth+_FUZZ or H>maxHeight+_FUZZ)):
             ident = 'content %sx%s too large for %s' % (W,H,self.identity(30))
             #leave to keep apart from the raise
@@ -1075,7 +1094,8 @@ class KeepInFrame(_Container,Flowable):
             self.height = min(maxHeight,H)-_FUZZ
         else:
             def func(x):
-                W, H = _listWrapOn(self._content,x*maxWidth,self.canv)
+                x = float(x)
+                W, H = _listWrapOn(self._content,x*maxWidth,self.canv, fakeWidth=fakeWidth)
                 W /= x
                 H /= x
                 return W, H
@@ -1084,7 +1104,7 @@ class KeepInFrame(_Container,Flowable):
             s0 = 1
             if W>maxWidth+_FUZZ:
                 #squeeze out the excess width and or Height
-                s1 = W/maxWidth
+                s1 = W/maxWidth     #linear model
                 W, H = func(s1)
                 if H<=maxHeight+_FUZZ:
                     self.width = W-_FUZZ
@@ -1187,10 +1207,14 @@ class ImageAndFlowables(_Container,Flowable):
         irpad = self._irpad
         ibpad = self._ibpad
         itpad = self._itpad
-        self._iW = availWidth - irpad - wI - ilpad
+        self._iW = iW = availWidth - irpad - wI - ilpad
         aH = itpad + hI + ibpad
-        W,H0,self._C0,self._C1 = self._findSplit(canv,self._iW,aH)
-        if W>self._iW+_FUZZ:
+        if iW>_FUZZ:
+            W,H0,self._C0,self._C1 = self._findSplit(canv,iW,aH)
+        else:
+            W = availWidth
+            H0 = 0
+        if W>iW+_FUZZ:
             self._C0 = []
             self._C1 = self._content
         aH = self._aH = max(aH,H0)
@@ -1956,3 +1980,17 @@ class DocWhile(DocIf):
         if bool(self.funcWrap(aW,aH)):
             self.add_content(*(list(self.block)+[self]))
         return 0,0
+
+class SetTopFlowables(NullDraw):
+    _ZEROZSIZE = 1
+    def __init__(self,F,show=False):
+        self._F = F
+        self._show = show
+
+    def wrap(self,aW,aH):
+        doc = getattr(getattr(self,'canv',None),'_doctemplate',None)
+        if doc:
+            doc._topFlowables=self._F
+            if self._show and self._F:
+                doc.frame._generated_content = self._F
+        return 0,0
