@@ -1,8 +1,8 @@
-#Copyright ReportLab Europe Ltd. 2000-2012
+#Copyright ReportLab Europe Ltd. 2000-2016
 #see license.txt for license details
 #history http://www.reportlab.co.uk/cgi-bin/viewcvs.cgi/public/reportlab/trunk/reportlab/platypus/frames.py
 
-__version__=''' $Id$ '''
+__version__='3.3.0'
 
 __doc__="""A frame is a container for content on a page.
 """
@@ -11,7 +11,7 @@ import logging
 logger = logging.getLogger('reportlab.platypus')
 
 _geomAttr=('x1', 'y1', 'width', 'height', 'leftPadding', 'bottomPadding', 'rightPadding', 'topPadding')
-from reportlab import rl_config
+from reportlab import rl_config, isPy3
 _FUZZ=rl_config._FUZZ
 
 class ShowBoundaryValue:
@@ -19,8 +19,13 @@ class ShowBoundaryValue:
         self.color = color
         self.width = width
 
-    def __bool__(self):
-        return self.color is not None and self.width>=0
+    if isPy3:
+        def __bool__(self):
+            return self.color is not None and self.width>=0
+    else:
+        def __nonzero__(self):
+            return self.color is not None and self.width>=0
+
 
 class Frame:
     '''
@@ -150,14 +155,15 @@ class Frame:
             p = self._y1p
             s = 0
             aW = self._getAvailableWidth()
+            zeroSize = getattr(flowable,'_ZEROSIZE',False)
             if not self._atTop:
                 s =flowable.getSpaceBefore()
                 if self._oASpace:
-                    if getattr(flowable,'_SPACETRANSFER',False):
+                    if getattr(flowable,'_SPACETRANSFER',False) or zeroSize:
                         s = self._prevASpace
                     s = max(s-self._prevASpace,0)
             h = y - p - s
-            if h>0:
+            if h>0 or zeroSize:
                 w, h = flowable.wrap(aW, h)
             else:
                 return 0
