@@ -1,7 +1,7 @@
-#Copyright ReportLab Europe Ltd. 2000-2012
+#Copyright ReportLab Europe Ltd. 2000-2016
 #see license.txt for license details
 #history http://www.reportlab.co.uk/cgi-bin/viewcvs.cgi/public/reportlab/trunk/reportlab/platypus/paraparser.py
-__version__=''' $Id$ '''
+__version__='3.3.0'
 __doc__='''The parser used to process markup within paragraphs'''
 import string
 import re
@@ -10,16 +10,11 @@ import os
 import copy
 import base64
 from pprint import pprint as pp
-
-try:
-    import pickle as pickle
-except:
-    import pickle
 import unicodedata
 import reportlab.lib.sequencer
 
 from reportlab.lib.abag import ABag
-from reportlab.lib.utils import ImageReader, isPy3, annotateException, encode_label, asUnicode, asBytes, uniChr
+from reportlab.lib.utils import ImageReader, isPy3, annotateException, encode_label, asUnicode, asBytes, uniChr, isStr
 from reportlab.lib.colors import toColor, white, black, red, Color
 from reportlab.lib.fonts import tt2ps, ps2tt
 from reportlab.lib.enums import TA_LEFT, TA_RIGHT, TA_CENTER, TA_JUSTIFY
@@ -35,7 +30,7 @@ _re_para = re.compile(r'^\s*<\s*para(?:\s+|>|/>)')
 
 sizeDelta = 2       # amount to reduce font size by for super and sub script
 subFraction = 0.5   # fraction of font size that a sub script should be lowered
-superFraction = 0.5 # fraction of font size that a super script should be raised
+supFraction = 0.5 # fraction of font size that a super script should be raised
 
 DEFAULT_INDEX_NAME='_indexAdd'
 
@@ -76,6 +71,20 @@ def _num(s, unit=1, allowRelative=True):
         s = s[:-4]
     return _convnum(s,unit,allowRelative)
 
+def _int(s):
+    try:
+        return int(s)
+    except:
+        raise ValueError('cannot convert %r to int' % s)
+
+def _bool(s):
+    s = s.lower()
+    if s in ('true','1','yes'):
+        return True
+    if s in ('false','0','no'):
+        return False
+    raise ValueError('cannot convert %r to bool value' % s)
+
 def _numpct(s,unit=1,allowRelative=False):
     if s.endswith('%'):
         return _PCT(_convnum(s[:-1],allowRelative=allowRelative))
@@ -116,7 +125,27 @@ def _align(s):
     elif s=='right': return TA_RIGHT
     elif s=='justify': return TA_JUSTIFY
     elif s in ('centre','center'): return TA_CENTER
-    else: raise ValueError
+    else: raise ValueError('illegal alignment %r' % s)
+
+def _bAnchor(s):
+    s = s.lower()
+    if not s in ('start','middle','end','numeric'):
+        raise ValueError('illegal bullet anchor %r' % s)
+    return s
+
+def _wordWrapConv(s):
+    s = s.upper().strip()
+    if not s: return None
+    if s not in ('CJK','RTL','LTR'):
+        raise ValueError('cannot convert wordWrap=%r' % s)
+    return s
+
+def _textTransformConv(s):
+    s = s.lower().strip()
+    if not s: return None
+    if s not in ('uppercase','lowercase','capitalize','none'):
+        raise ValueError('cannot convert wordWrap=%r' % s)
+    return s
 
 _paraAttrMap = {'font': ('fontName', None),
                 'face': ('fontName', None),
@@ -135,11 +164,25 @@ _paraAttrMap = {'font': ('fontName', None),
                 'boffsety': ('bulletOffsetY',_num),
                 'bindent': ('bulletIndent',_num),
                 'bcolor': ('bulletColor',toColor),
+                'banchor': ('bulletAnchor',_bAnchor),
                 'color':('textColor',toColor),
                 'backcolor':('backColor',toColor),
                 'bgcolor':('backColor',toColor),
                 'bg':('backColor',toColor),
                 'fg': ('textColor',toColor),
+                'justifybreaks': ('justifyBreaks',_bool),
+                'justifylastline': ('justifyLastLine',_int),
+                'wordwrap': ('wordWrap',_wordWrapConv),
+                'allowwidows': ('allowWidows',_bool),
+                'alloworphans': ('allowOrphans',_bool),
+                'splitlongwords': ('splitLongWords',_bool),
+                'borderwidth': ('borderWidth',_num),
+                'borderpadding': ('borderpadding',_num),
+                'bordercolor': ('borderColor',toColor),
+                'borderradius': ('borderRadius',_num),
+                'texttransform':('textTransform',_textTransformConv),
+                'enddots':('endDots',None),
+                'underlineproportion':('underlineProportion',_num),
                 }
 
 _bulletAttrMap = {
@@ -151,6 +194,7 @@ _bulletAttrMap = {
                 'indent': ('bulletIndent',_num),
                 'color': ('bulletColor',toColor),
                 'fg': ('bulletColor',toColor),
+                'anchor': ('bulletAnchor',_bAnchor),
                 }
 
 #things which are valid font attributes
@@ -206,6 +250,10 @@ _indexAttrMap = {
                 'offset': ('offset',None),
                 'format': ('format',None),
                 }
+_supAttrMap = {
+                'rise': ('supr', _num),
+                'size': ('sups', _num),
+                }
 
 def _addAttributeNames(m):
     K = list(m.keys())
@@ -537,9 +585,9 @@ def _greekConvert(data):
 #       < /i > - italics
 #       < u > < /u > - underline
 #       < strike > < /strike > - strike through
-#       < super > < /super > - superscript
-#       < sup > < /sup > - superscript
-#       < sub > < /sub > - subscript
+#       < super [size="pts"] [rise="pts"]> < /super > - superscript
+#       < sup ="pts"] [rise="pts"]> < /sup > - superscript
+#       < sub ="pts"] [rise="pts"]> < /sub > - subscript
 #       <font name=fontfamily/fontname color=colorname size=float>
 #        <span name=fontfamily/fontname color=colorname backcolor=colorname size=float style=stylename>
 #       < bullet > </bullet> - bullet text (at head of para only)
@@ -596,52 +644,51 @@ class ParaParser(HTMLParser):
 
     #### bold
     def start_b( self, attributes ):
-        self._push(bold=1)
+        self._push('b',bold=1)
 
     def end_b( self ):
-        self._pop(bold=1)
+        self._pop('b')
 
     def start_strong( self, attributes ):
-        self._push(bold=1)
+        self._push('strong',bold=1)
 
     def end_strong( self ):
-        self._pop(bold=1)
+        self._pop('strong')
 
     #### italics
     def start_i( self, attributes ):
-        self._push(italic=1)
+        self._push('i',italic=1)
 
     def end_i( self ):
-        self._pop(italic=1)
+        self._pop('i')
 
     def start_em( self, attributes ):
-        self._push(italic=1)
+        self._push('em', italic=1)
 
     def end_em( self ):
-        self._pop(italic=1)
+        self._pop('em')
 
     #### underline
     def start_u( self, attributes ):
-        self._push(underline=1)
+        self._push('u',underline=1)
 
     def end_u( self ):
-        self._pop(underline=1)
+        self._pop('u')
 
     #### strike
     def start_strike( self, attributes ):
-        self._push(strike=1)
+        self._push('strike',strike=1)
 
     def end_strike( self ):
-        self._pop(strike=1)
+        self._pop('strike')
 
     #### link
     def start_link(self, attributes):
-        self._push(**self.getAttributes(attributes,_linkAttrMap))
+        self._push('link',**self.getAttributes(attributes,_linkAttrMap))
 
     def end_link(self):
-        frag = self._stack[-1]
-        del self._stack[-1]
-        assert frag.link!=None
+        if self._pop('link').link is None:
+            raise ValueError('<link> has no target or href')
 
     #### anchor
     def start_a(self, attributes):
@@ -659,33 +706,35 @@ class ParaParser(HTMLParser):
             href = A.get('href','').strip()
             A['link'] = href    #convert to our link form
             A.pop('href',None)
-        self._push(**A)
+        self._push('a',**A)
 
     def end_a(self):
         frag = self._stack[-1]
         sct = getattr(frag,'_selfClosingTag','')
         if sct:
-            assert sct=='anchor' and frag.name,'Parser failure in <a/>'
+            if not (sct=='anchor' and frag.name):
+                raise ValueError('Parser failure in <a/>')
             defn = frag.cbDefn = ABag()
             defn.label = defn.kind = 'anchor'
             defn.name = frag.name
             del frag.name, frag._selfClosingTag
             self.handle_data('')
-            self._pop()
+            self._pop('a')
         else:
-            del self._stack[-1]
-            assert frag.link!=None
+            if self._pop('a').link is None:
+                raise ValueError('<link> has no href')
 
     def start_img(self,attributes):
         A = self.getAttributes(attributes,_imgAttrMap)
         if not A.get('src'):
             self._syntax_error('<img> needs src attribute')
         A['_selfClosingTag'] = 'img'
-        self._push(**A)
+        self._push('img',**A)
 
     def end_img(self):
         frag = self._stack[-1]
-        assert getattr(frag,'_selfClosingTag',''),'Parser failure in <img/>'
+        if not getattr(frag,'_selfClosingTag',''):
+            raise ValueError('Parser failure in <img/>')
         defn = frag.cbDefn = ABag()
         defn.kind = 'img'
         defn.src = getattr(frag,'src',None)
@@ -696,24 +745,33 @@ class ParaParser(HTMLParser):
         defn.valign = getattr(frag,'valign','bottom')
         del frag._selfClosingTag
         self.handle_data('')
-        self._pop()
+        self._pop('img')
 
     #### super script
     def start_super( self, attributes ):
-        self._push(super=1)
+        A = self.getAttributes(attributes,_supAttrMap)
+        A['sup']=1
+        self._push('super',**A)
 
     def end_super( self ):
-        self._pop(super=1)
+        self._pop('super')
 
-    start_sup = start_super
-    end_sup = end_super
+    def start_sup( self, attributes ):
+        A = self.getAttributes(attributes,_supAttrMap)
+        A['sup']=1
+        self._push('sup',**A)
+
+    def end_sup( self ):
+        self._pop('sup')
 
     #### sub script
     def start_sub( self, attributes ):
-        self._push(sub=1)
+        A = self.getAttributes(attributes,_supAttrMap)
+        A['sub']=1
+        self._push('sub',**A)
 
     def end_sub( self ):
-        self._pop(sub=1)
+        self._pop('sub')
 
     #### greek script
     #### add symbol encoding
@@ -736,10 +794,10 @@ class ParaParser(HTMLParser):
         self.errors.append(message)
 
     def start_greek(self, attr):
-        self._push(greek=1)
+        self._push('greek',greek=1)
 
     def end_greek(self):
-        self._pop(greek=1)
+        self._pop('greek')
 
     def start_unichar(self, attr):
         if 'name' in attr:
@@ -748,7 +806,7 @@ class ParaParser(HTMLParser):
             try:
                 v = unicodedata.lookup(attr['name'])
             except KeyError:
-                self._syntax_error('<unichar/> invalid name attribute\n"%s"' % ascii(name))
+                self._syntax_error('<unichar/> invalid name attribute\n"%s"' % ascii(attr['name']))
                 v = '\0'
         elif 'code' in attr:
             try:
@@ -764,16 +822,19 @@ class ParaParser(HTMLParser):
 
         if v is not None:
             self.handle_data(v)
-        self._push(_selfClosingTag='unichar')
+        self._push('unichar',_selfClosingTag='unichar')
 
     def end_unichar(self):
-        self._pop()
+        self._pop('unichar')
 
     def start_font(self,attr):
-        self._push(**self.getAttributes(attr,_fontAttrMap))
+        A = self.getAttributes(attr,_spanAttrMap)
+        if 'fontName' in A:
+            A['fontName'], A['bold'], A['italic'] = ps2tt(A['fontName'])
+        self._push('font',**A)
 
     def end_font(self):
-        self._pop()
+        self._pop('font')
 
     def start_span(self,attr):
         A = self.getAttributes(attr,_spanAttrMap)
@@ -786,20 +847,24 @@ class ParaParser(HTMLParser):
                 D[k] = v
             D.update(A)
             A = D
-        self._push(**A)
+        if 'fontName' in A:
+            A['fontName'], A['bold'], A['italic'] = ps2tt(A['fontName'])
+        self._push('span',**A)
 
-    end_span = end_font
+    def end_span(self):
+        self._pop('span')
 
     def start_br(self, attr):
-        self._push(_selfClosingTag='br',lineBreak=True,text='')
+        self._push('br',_selfClosingTag='br',lineBreak=True,text='')
         
     def end_br(self):
         #print('\nend_br called, %d frags in list' % len(self.fragList))
         frag = self._stack[-1]
-        assert frag._selfClosingTag=='br' and frag.lineBreak,'Parser failure in <br/>'
+        if not (frag._selfClosingTag=='br' and frag.lineBreak):
+                raise ValueError('Parser failure in <br/>')
         del frag._selfClosingTag
         self.handle_data('')
-        self._pop()
+        self._pop('br')
 
     def _initial_frag(self,attr,attrMap,bullet=0):
         style = self._style
@@ -811,7 +876,7 @@ class ParaParser(HTMLParser):
         # initialize semantic values
         frag = ParaFrag()
         frag.sub = 0
-        frag.super = 0
+        frag.sup = 0
         frag.rise = 0
         frag.underline = 0
         frag.strike = 0
@@ -828,10 +893,12 @@ class ParaParser(HTMLParser):
         return frag
 
     def start_para(self,attr):
-        self._stack = [self._initial_frag(attr,_paraAttrMap)]
+        frag = self._initial_frag(attr,_paraAttrMap)
+        frag.__tag__ = 'para'
+        self._stack = [frag]
 
     def end_para(self):
-        self._pop()
+        self._pop('para')
 
     def start_bullet(self,attr):
         if hasattr(self,'bFragList'):
@@ -839,10 +906,11 @@ class ParaParser(HTMLParser):
         self.bFragList = []
         frag = self._initial_frag(attr,_bulletAttrMap,1)
         frag.isBullet = 1
+        frag.__tag__ = 'bullet'
         self._stack.append(frag)
 
     def end_bullet(self):
-        self._pop()
+        self._pop('bullet')
 
     #---------------------------------------------------------------
     def start_seqdefault(self, attr):
@@ -938,9 +1006,9 @@ class ParaParser(HTMLParser):
 
         if 'label' in attr: defn.label = attr['label']
         defn.kind='onDraw'
-        self._push(cbDefn=defn)
+        self._push('ondraw',cbDefn=defn)
         self.handle_data('')
-        self._pop()
+        self._pop('ondraw')
     start_onDraw=start_ondraw 
     end_onDraw=end_ondraw=end_seq
 
@@ -967,9 +1035,9 @@ class ParaParser(HTMLParser):
         defn.label = encode_label((label,format,offset))
         defn.name = name
         defn.kind='index'
-        self._push(cbDefn=defn)
+        self._push('index',cbDefn=defn)
         self.handle_data('')
-        self._pop()
+        self._pop('index',)
     end_index=end_seq
 
     def start_unknown(self,attr):
@@ -977,24 +1045,23 @@ class ParaParser(HTMLParser):
     end_unknown=end_seq
 
     #---------------------------------------------------------------
-    def _push(self,**attr):
+    def _push(self,tag,**attr):
         frag = copy.copy(self._stack[-1])
+        frag.__tag__ = tag
         _applyAttributes(frag,attr)
         self._stack.append(frag)
 
-    def _pop(self,**kw):
-        frag = self._stack[-1]
-        del self._stack[-1]
-        for k, v in kw.items():
-            assert getattr(frag,k)==v
-        return frag
+    def _pop(self,tag):
+        frag = self._stack.pop()
+        if tag==frag.__tag__: return frag
+        raise ValueError('Parse error: saw </%s> instead of expected </%s>' % (tag,frag.__tag__))
 
     def getAttributes(self,attr,attrMap):
         A = {}
         for k, v in attr.items():
             if not self.caseSensitive:
                 k = k.lower()
-            if k in list(attrMap.keys()):
+            if k in attrMap:
                 j = attrMap[k]
                 func = j[1]
                 try:
@@ -1002,6 +1069,7 @@ class ParaParser(HTMLParser):
                 except:
                     self._syntax_error('%s: invalid value %s'%(k,v))
             else:
+                raise ValueError('invalid attribute name %s attrMap=%r'% (k,list(sorted(attrMap.keys()))))
                 self._syntax_error('invalid attribute name %s'%k)
         return A
 
@@ -1047,17 +1115,17 @@ class ParaParser(HTMLParser):
             if data!='': self._syntax_error('No content allowed in %s tag' % frag._selfClosingTag)
             return
         else:
-            # if sub and super are both on they will cancel each other out
-            if frag.sub == 1 and frag.super == 1:
+            # if sub and sup are both on they will cancel each other out
+            if frag.sub == 1 and frag.sup == 1:
                 frag.sub = 0
-                frag.super = 0
+                frag.sup = 0
 
             if frag.sub:
-                frag.rise = -frag.fontSize*subFraction
-                frag.fontSize = max(frag.fontSize-sizeDelta,3)
-            elif frag.super:
-                frag.rise = frag.fontSize*superFraction
-                frag.fontSize = max(frag.fontSize-sizeDelta,3)
+                frag.rise = -getattr(frag,'supr',frag.fontSize*subFraction)
+                frag.fontSize = getattr(frag,'sups',frag.fontSize-min(sizeDelta,0.2*frag.fontSize))
+            elif frag.sup:
+                frag.rise = getattr(frag,'supr',frag.fontSize*supFraction)
+                frag.fontSize = getattr(frag,'sups',frag.fontSize-min(sizeDelta,0.2*frag.fontSize))
 
             if frag.greek:
                 frag.fontName = 'symbol'
@@ -1148,7 +1216,7 @@ class ParaParser(HTMLParser):
         try:
             self.feed(text)
         except:
-            annotateException('paragraph text %s caused exception' % ascii(text))
+            annotateException('\nparagraph text %s caused exception' % ascii(text))
         return self._complete_parse()
 
     def handle_starttag(self, tag, attrs):
