@@ -1,4 +1,4 @@
-#Copyright ReportLab Europe Ltd. 2000-2013
+#Copyright ReportLab Europe Ltd. 2000-2016
 #see license.txt for license details
 '''default settings for reportlab
 
@@ -6,7 +6,7 @@ to override these drop a module rl_local_settings.py parallel to this file or
 anywhere on the path.
 '''
 import os, sys
-__version__=''' $Id$ '''
+__version__='3.3.0'
 __all__=tuple('''allowTableBoundsErrors
 shapeChecking
 defaultEncoding
@@ -43,9 +43,15 @@ ttfAsciiReadable
 pdfMultiLine
 pdfComments
 debug
+rtlSupport
+listWrapOnFakeWidth
 T1SearchPath
 TTFSearchPath
-CMapSearchPath'''.split())
+CMapSearchPath
+baseUnderlineProportion
+decimalSymbol
+errorOnDuplicatePageLabelPage
+autoGenerateMissingTTFName'''.split())
 
 allowTableBoundsErrors =    1 # set to 0 to die on too large elements in tables in debug (recommend 1 for production use)
 shapeChecking =             1
@@ -92,6 +98,14 @@ ttfAsciiReadable=           1                       #smaller subsets when set to
 pdfMultiLine=               0                       #use more lines in pdf etc
 pdfComments=                0                       #put in pdf comments
 debug=                      0                       #for debugging code
+rtlSupport=                 0                       #set to 1 to attempt import of RTL assistance eg fribidi etc etc
+listWrapOnFakeWidth=        1                       #set to 0/False to force platypus.flowables._listWrapOn to report correct widths
+                                                    #else it reports minimum(required,available) width
+baseUnderlineProportion=    0.0                     #non-zero for doing font size proportional lines in Paragraph.py
+                                                    #by default typical value 0.05. may be overridden on a parastyle.
+decimalSymbol=              '.'                     #what we use to align floats numerically
+errorOnDuplicatePageLabelPage= 0                    #if True will cause repeated PageLabel page numbers to raise an error.
+autoGenerateMissingTTFName=0                        #if true we try to auto generate any missing TTF font name
 
 # places to look for T1Font information
 T1SearchPath =  (
@@ -114,6 +128,7 @@ T1SearchPath =  (
                 '/usr/local/Acrobat6/Resource/Font',    #Linux, Acrobat 5?
                 '/usr/local/Acrobat5/Resource/Font',    #Linux, Acrobat 5?
                 '/usr/local/Acrobat4/Resource/Font',    #Linux, Acrobat 4
+                '/usr/share/fonts/default/Type1',       #Linux, Fedora
                 '%(REPORTLAB_DIR)s/fonts',              #special
                 '%(REPORTLAB_DIR)s/../fonts',           #special
                 '%(REPORTLAB_DIR)s/../../fonts',        #special
@@ -130,6 +145,8 @@ TTFSearchPath = (
                 'c:/windows/fonts',
                 '/usr/lib/X11/fonts/TrueType/',
                 '/usr/share/fonts/truetype',
+                '/usr/share/fonts',             #Linux, Fedora
+                '/usr/share/fonts/dejavu',      #Linux, Fedora
                 '%(REPORTLAB_DIR)s/fonts',      #special
                 '%(REPORTLAB_DIR)s/../fonts',   #special
                 '%(REPORTLAB_DIR)s/../../fonts',#special
