@@ -1,6 +1,6 @@
-#Copyright ReportLab Europe Ltd. 2000-2012
+#Copyright ReportLab Europe Ltd. 2000-2016
 #see license.txt for license details
-__version__=''' $Id$ '''
+__version__='3.3.0'
 
 #tests and documents Page Layout API
 __doc__="""This is not obvious so here's a brief explanation.  This module is both
@@ -560,7 +560,6 @@ def run():
 
 
 class PlatypusTestCase(unittest.TestCase):
-    "Make documents with lots of Platypus features"
 
     def test0(self):
         "Make a platypus document"
@@ -582,6 +581,16 @@ class PlatypusTestCase(unittest.TestCase):
         doc = SimpleDocTemplate(outputfile('test_drawing_keepwithnext.pdf'))
         doc.build(story)
 
+    def test2(self):
+        '''ensure showBoundaryValue works as expected'''
+        from reportlab.platypus.frames import ShowBoundaryValue
+        assert (1 if ShowBoundaryValue(width=1) else 0) == 1
+        assert (1 if ShowBoundaryValue(color=None,width=1) else 0) == 0
+        assert (1 if ShowBoundaryValue(width=-1) else 0) == 0
+        assert bool(ShowBoundaryValue(width=1)) == True
+        assert bool(ShowBoundaryValue(color=None,width=1)) == False
+        assert bool(ShowBoundaryValue(width=-1)) == False
+
 def makeSuite():
     return makeSuiteForClasses(PlatypusTestCase)
 
