@@ -1,8 +1,8 @@
-#Copyright ReportLab Europe Ltd. 2000-2012
+#Copyright ReportLab Europe Ltd. 2000-2016
 #see license.txt for license details
 """Tests for the reportlab.platypus.paragraphs module.
 """
-__version__=''' $Id$ '''
+__version__='3.3.0'
 from reportlab.lib.testutils import setOutDir,makeSuiteForClasses, outputfile, printLocation
 setOutDir(__name__)
 import sys, os, unittest
@@ -528,6 +528,32 @@ phonemic and <u>morphological</u> <strike>analysis</strike>.'''
             a(Paragraph(fmt % dict(valign=valign,testsFolder=testsFolder),p_style))
             a(XPreformatted(fmt % dict(valign=valign,testsFolder=testsFolder),p_style))
 
+        a(Paragraph('<br/><b>Some Paragraph tests of &lt;sup rise="pts" size="pts"</b>...', normal))
+        a(Paragraph("<br/>This is a <sup><span color='red'>sup</span></sup>.",p_style))
+        a(XPreformatted("This is a <sup><span color='red'>sup</span></sup>.",p_style))
+        a(Paragraph("This is a <sup rise=5><span color='red'>sup</span></sup>rise=5.",p_style))
+        a(XPreformatted("This is a <sup rise=5><span color='red'>sup</span></sup>rise=5.",p_style))
+        a(Paragraph("This is a <sup rise=6><span color='red'>sup</span></sup>rise=6.",p_style))
+        a(XPreformatted("This is a <sup rise=6><span color='red'>sup</span></sup>rise=6.",p_style))
+        a(Paragraph("This is a <sup rise=7><span color='red'>sup</span></sup>rise=7.",p_style))
+        a(XPreformatted("This is a <sup rise=7><span color='red'>sup</span></sup>rise=7.",p_style))
+        a(Paragraph("This is a <sup rise=8><span color='red'>sup</span></sup>rise=8.",p_style))
+        a(XPreformatted("This is a <sup rise=8><span color='red'>sup</span></sup>rise=8.",p_style))
+        a(Paragraph("This is a <sup rise=9><span color='red'>sup</span></sup>rise=9.",p_style))
+        a(XPreformatted("This is a <sup rise=9><span color='red'>sup</span></sup>rise=9.",p_style))
+        a(Paragraph("This is a <sup size=7><span color='red'>sup</span></sup>size=7.",p_style))
+        a(XPreformatted("This is a <sup size=7><span color='red'>sup</span></sup>size=7.",p_style))
+        a(Paragraph("This is a <sup rise=5 size=7><span color='red'>sup</span></sup>rise=5 size=7.",p_style))
+        a(XPreformatted("This is a <sup rise=5 size=7><span color='red'>sup</span></sup>rise=5 size=7.",p_style))
+        a(Paragraph("This is a <sup rise=6 size=7><span color='red'>sup</span></sup>rise=6 size=7.",p_style))
+        a(XPreformatted("This is a <sup rise=6 size=7><span color='red'>sup</span></sup>rise=6 size=7.",p_style))
+        a(Paragraph("This is a <sup rise=7 size=7><span color='red'>sup</span></sup>rise=7 size=7.",p_style))
+        a(XPreformatted("This is a <sup rise=7 size=7><span color='red'>sup</span></sup>rise=7 size=7.",p_style))
+        a(Paragraph("This is a <sup rise=8 size=7><span color='red'>sup</span></sup>rise=8 size=7.",p_style))
+        a(XPreformatted("This is a <sup rise=8 size=7><span color='red'>sup</span></sup>rise=8 size=7.",p_style))
+        a(Paragraph("This is a <sup rise=9 size=7><span color='red'>sup</span></sup>rise=9 size=7.",p_style))
+        a(XPreformatted("This is a <sup rise=9 size=7><span color='red'>sup</span></sup>rise=9 size=7.",p_style))
+        a(PageBreak())
 
         a(Paragraph('<br/><b>Some Paragraph tests of &lt;img width="x%" height="x%"</b>...', normal))
         a(Paragraph('H=10%% <img src="%(testsFolder)s/../docs/images/testimg.gif" width="0.57in" height="10%%" />'%dict(testsFolder=testsFolder), normal))
@@ -583,8 +609,9 @@ linguistics can be defined in such a way as to impose problems of
 phonemic and morphological analysis.'''
         story =[]
         a = story.append
-        for mode in (0,1,2,3,4):
+        for mode in (0,1,2,3,4,5,6,7):
             text = text0
+            paraStyle = normal_just
             if mode==1:
                 text = text.replace('English sentences','<b>English sentences</b>').replace('quite equivalent','<i>quite equivalent</i>')
                 text = text.replace('the methodological work','<b>the methodological work</b>').replace('to impose problems','<i>to impose problems</i>')
@@ -599,10 +626,26 @@ phonemic and morphological analysis.'''
                 text = text.replace('English ','English&nbsp;').replace('quite ','quite&nbsp;')
                 text = text.replace(' methodological','&nbsp;methodological').replace(' impose','&nbsp;impose')
                 a(Paragraph('Justified paragraph in normal font &amp; some hard spaces',style=normal))
+            elif mode in (5,6,7):
+                text = text.replace('as to impose','<br/>as to impose').replace(' most of the','<br/>most of the')
+                text = text.replace(' grounds','<br/>grounds').replace(' various','<br/>various')
+                if mode in (6,7):
+                    msg = []
+                    msg.append('justifyBreaks=1')
+                    paraStyle = paraStyle.clone('paraStyle6',paraStyle,justifyBreaks=1)
+                    if mode==7:
+                        msg.append('justifyLastLine=3')
+                        paraStyle = paraStyle.clone('paraStyle7',paraStyle,justifyLastLine=3)
+                    msg = '(%s) ' % (' '.join(msg))
+                else:
+                    a(PageBreak())
+                    msg = ' '
+
+                a(Paragraph('Justified%swith some &lt;br/&gt; tags' % msg,style=normal))
             else:
                 a(Paragraph('Justified paragraph in normal font',style=normal))
 
-            a(Paragraph(text,style=normal_just))
+            a(Paragraph(text,style=paraStyle))
         doc = MyDocTemplate(outputfile('test_platypus_paragraphs_just.pdf'))
         doc.build(story)
 
