@@ -1,9 +1,9 @@
 #!/bin/env python
-#Copyright ReportLab Europe Ltd. 2000-2012
+#Copyright ReportLab Europe Ltd. 2000-2016
 #see license.txt for license details
 #history TBC
 #$Header$
-__version__=''' $Id'''
+__version__='3.3.0'
 __doc__="""Tests of intra-paragraph parsing behaviour in Platypus."""
 from reportlab.lib.testutils import setOutDir,makeSuiteForClasses, outputfile, equalStrings
 setOutDir(__name__)
@@ -104,6 +104,16 @@ class ParaParserTestCase(unittest.TestCase):
         self.assertEquals([x.text for x in fragList], ['Hello ','',' World'])
         self.assertEquals(fragList[1].lineBreak, True)
 
+
+    def testRejectsBadlyFormed(self):
+        txt = "Hello <b>World"
+
+        def parseIt(txt, style=self.style):
+            fragList = ParaParser().parse(txt, self.style)[1]
+
+        self.assertRaises(ValueError, parseIt, txt)
+        
+
     #def testNakedAmpersands(self):
         #We no longer require this error to be raised when using html.parser
         # import pyRXPU
