@@ -2,7 +2,7 @@
 #Copyright ReportLab Europe Ltd. 2000-2012
 #see license.txt for license details
 #history http://www.reportlab.co.uk/cgi-bin/viewcvs.cgi/public/reportlab/trunk/reportlab/tools/docco/rl_doc_utils.py
-__version__=''' $Id$ '''
+__version__='3.3.0'
 
 __doc__ = """
 This module contains utilities for generating guides
@@ -28,6 +28,7 @@ from reportlab.platypus.xpreformatted import PythonPreformatted
 from reportlab.lib.styles import ParagraphStyle
 from reportlab.lib import colors
 from reportlab.lib.sequencer import getSequencer
+from xml.sax.saxutils import escape as xmlEscape
 
 from . import examples
 
@@ -39,7 +40,6 @@ QFreptemplate = Template("X^X^", "X")
 codesubst = "%s<font name=Courier>%s</font>"
 QFsubst = "%s<font name=Courier><i>%s</i></font>"
 
-
 def quickfix(text):
     """inside text find any subsequence of form $subsequence$.
        Format the subsequence as code.  If similarly if text contains ^arg^
@@ -68,8 +68,6 @@ def quickfix(text):
     return text
 #print quickfix("$testing$ testing $one$ ^two^ $three(^four^)$")
 
-
-
 H1 = styleSheet['Heading1']
 H2 = styleSheet['Heading2']
 H3 = styleSheet['Heading3']
@@ -362,7 +360,7 @@ class ParaBox2(figures.Figure):
                                 leading=9.6)
         textStyle = B
         self.text = text
-        self.left = Paragraph('<![CDATA[' + text + ']]>', descrStyle)
+        self.left = Paragraph(xmlEscape(text), descrStyle)
         self.right = Paragraph(text, B)
 
 
